summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJuergen Bocklage-Ryannel <juergen.bocklage-ryannel@pelagicore.com>2017-01-20 08:57:31 +0100
committerJuergen Bocklage-Ryannel <juergen.bocklage-ryannel@pelagicore.com>2017-01-20 08:57:31 +0100
commit88d9cee3bcb11bf597a47df7578e3929641d2072 (patch)
tree49909d576beeeb43a5313aa65b14f67bdba93bdd
parentaf81b318f31b8b4d53600f27385e2b41dd8cb738 (diff)
downloadqtivi-qface-88d9cee3bcb11bf597a47df7578e3929641d2072.tar.gz
changed QDL wording to QFace document
-rw-r--r--docs/grammar.rst16
-rw-r--r--docs/index.rst2
-rw-r--r--docs/usage.rst2
-rw-r--r--qface/idl/domain.py11
4 files changed, 17 insertions, 14 deletions
diff --git a/docs/grammar.rst b/docs/grammar.rst
index 1998025..8fe04bb 100644
--- a/docs/grammar.rst
+++ b/docs/grammar.rst
@@ -1,8 +1,8 @@
===========
-QDL Grammar
+QFace Grammar
===========
-QDL (Qt definition language) is an IDL to define an interface. In general it is modeled to define an interface between Qt QML and C++. The QDL syntax is flexible enough also to be used in other context.
+QFace (Qt interface language) is an IDL to define an interface. In general it is modeled to define an interface between Qt QML and C++. The QFace syntax is flexible enough also to be used in other context.
.. code-block:: html
@@ -27,13 +27,13 @@ QDL (Qt definition language) is an IDL to define an interface. In general it is
<name> = <value>,
}
-A QDL document always describes one module. Each document can contain one or more interfaces, structs, flags or enums. Each document can import other modules using the import statement.
+A QFace document always describes one module. Each document can contain one or more interfaces, structs, flags or enums. Each document can import other modules using the import statement.
Module
======
-A module is identified name. A module should be normally a URI where all parts are lowercase (e.g. `entertainment.tuner`). A module can import other modules. This is used to ensure that dependencies are declared inside the QDL file.
+A module is identified name. A module should be normally a URI where all parts are lowercase (e.g. `entertainment.tuner`). A module can import other modules. This is used to ensure that dependencies are declared inside the QFace file.
Types
-----
@@ -42,9 +42,9 @@ Types are either local and can be references simply by its name, or they are fro
A module consist of either one or more interfaces, structs and enums/flags. They can come in any number or combination. The interface is the only type which can contain operations and events. The struct is merely a container to transport structured data. An enum/flag allows the user to encode information used inside the struct or interface as datatype.
-The QDL does not allow to extend interfaces. It is by design kept simple.
+The QFace does not allow to extend interfaces. It is by design kept simple.
-Below is an example of a QDL file.
+Below is an example of a QFace file.
.. code-block:: js
@@ -61,7 +61,7 @@ Below is an example of a QDL file.
/*! operation previousStation */
void previousStation();
/*! operation updateCurrentStation */
- void updateCurrentStation(int stationId);
+ void updateCurrentStation(int stationId);
list<int> primitiveList;
list<Station> complexList;
@@ -102,7 +102,7 @@ Below is an example of a QDL file.
string name;
/*! last time modified */
common.TimeStamp modified;
- }
+ }
diff --git a/docs/index.rst b/docs/index.rst
index d2a2e6d..4a28a7f 100644
--- a/docs/index.rst
+++ b/docs/index.rst
@@ -1,7 +1,7 @@
QFace
=====
-QFace is a flexible Qt API generator. It uses a common IDL format (called QDL) to define an API. QFace comes with a set of predefined generators to generate QML Plugins. QFace can be easily extended with your own generator.
+QFace is a flexible Qt API generator. It uses a common IDL format (called QFace interface document) to define an API. QFace comes with a set of predefined generators to generate QML Plugins. QFace can be easily extended with your own generator.
.. toctree::
:maxdepth: 1
diff --git a/docs/usage.rst b/docs/usage.rst
index 32411f1..8cc059f 100644
--- a/docs/usage.rst
+++ b/docs/usage.rst
@@ -5,7 +5,7 @@ Usage
Concept
=======
-QFace requires one or more IDL files as input file and a generator to produce output files. The IDL files are named QDL (Qt definition language).
+QFace requires one or more IDL files as input file and a generator to produce output files. The IDL files are named QFace interface documents.
.. image:: qface_concept.png
diff --git a/qface/idl/domain.py b/qface/idl/domain.py
index 3b944a9..6a6ece9 100644
--- a/qface/idl/domain.py
+++ b/qface/idl/domain.py
@@ -1,7 +1,7 @@
# Copyright (c) Pelagicore AB 2016
'''The domian module contains an object hierachy which resembles the
-QDL grammar as a domain model. It is created from the QDL and the main
+QFace grammar as a domain model. It is created from the QFace and the main
input for the code generation templates.
.. note:: Changes on this API will result into broken templates
@@ -18,7 +18,10 @@ input for the code generation templates.
+- Struct (has attributes)
+- Enum (has values)
-.. note:: When the API talks about an order list, the order is by appearance in the QDL file.
+.. note::
+
+ When the API talks about an order list, the order is by appearance
+ in the QFace file.
'''
from collections import OrderedDict, ChainMap
@@ -75,10 +78,10 @@ class Symbol(object):
self.module = module
"""module the symbol belongs to"""
self.comment = ''
"""comment which appeared in QDL right before symbol"""
self._tags = OrderedDict()
-
+
@property
def system(self):
@@ -75,10 +78,10 @@ class Symbol(object):
"""module the symbol belongs to"""
self.comment = ''
- """comment which appeared in QDL right before symbol"""
+ """comment which appeared in QFace right before symbol"""
self._tags = OrderedDict()